
# Slot: subject


information content entity which an agent has helped realise

URI: [biolink:contributor_association_subject](https://w3id.org/biolink/vocab/contributor_association_subject)


## Domain and Range

[ContributorAssociation](ContributorAssociation.md) &#8594;  <sub>1..1</sub> [InformationContentEntity](InformationContentEntity.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [ContributorAssociation](ContributorAssociation.md)
